aboutsummaryrefslogtreecommitdiffstats
path: root/modules/mail/em-account-prefs.c
diff options
context:
space:
mode:
authorMilan Crha <mcrha@redhat.com>2009-08-18 22:00:23 +0800
committerMatthew Barnes <mbarnes@redhat.com>2009-08-18 22:00:23 +0800
commitde528db6c18b7ecee83bb8b52850d935c1244ebf (patch)
treee5c153870853da0f9e317f8eb5e78394e00bd528 /modules/mail/em-account-prefs.c
parent9ff9063fe66817737f89decc3fdadb473fa51278 (diff)
downloadgsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar.gz
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar.bz2
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar.lz
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar.xz
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.tar.zst
gsoc2013-evolution-de528db6c18b7ecee83bb8b52850d935c1244ebf.zip
BugĀ 567260 - Migrate from GnomeDruid to GtkAssistant
Diffstat (limited to 'modules/mail/em-account-prefs.c')
-rw-r--r--modules/mail/em-account-prefs.c34
1 files changed, 17 insertions, 17 deletions
diff --git a/modules/mail/em-account-prefs.c b/modules/mail/em-account-prefs.c
index f2c646d5ed..0f86cd8341 100644
--- a/modules/mail/em-account-prefs.c
+++ b/modules/mail/em-account-prefs.c
@@ -45,8 +45,8 @@
((obj), EM_TYPE_ACCOUNT_PREFS, EMAccountPrefsPrivate))
struct _EMAccountPrefsPrivate {
- gpointer druid; /* weak pointer */
- gpointer editor; /* weak pointer */
+ gpointer assistant; /* weak pointer */
+ gpointer editor; /* weak pointer */
};
static gpointer parent_class;
@@ -104,30 +104,30 @@ account_prefs_add_account (EAccountManager *manager)
priv = EM_ACCOUNT_PREFS_GET_PRIVATE (manager);
- if (priv->druid != NULL) {
- gtk_window_present (GTK_WINDOW (priv->druid));
+ if (priv->assistant != NULL) {
+ gtk_window_present (GTK_WINDOW (priv->assistant));
return;
}
parent = gtk_widget_get_toplevel (GTK_WIDGET (manager));
parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
/** @HookPoint-EMConfig: New Mail Account Druid
* @Id: org.gnome.evolution.mail.config.accountDruid
* @Type: E_CONFIG_DRUID
* @Class: org.gnome.evolution.mail.config:1.0
* @Target: EMConfigTargetAccount
*
* The new mail account druid.
*/
emae = em_account_editor_new (
- NULL, EMAE_DRUID,
- "org.gnome.evolution.mail.config.accountDruid");
- priv->druid = emae->editor;
+ NULL, EMAE_ASSISTANT,
+ "org.gnome.evolution.mail.config.accountAssistant");
+ priv->assistant = emae->editor;
- g_object_add_weak_pointer (G_OBJECT (priv->druid), &priv->druid);
- gtk_window_set_transient_for (GTK_WINDOW (priv->druid), parent);
- gtk_widget_show (priv->druid);
+ g_object_add_weak_pointer (G_OBJECT (priv->assistant), &priv->assistant);
+ gtk_window_set_transient_for (GTK_WINDOW (priv->assistant), parent);
+ gtk_widget_show (priv->assistant);
}
static void
@@ -232,10 +232,10 @@ account_prefs_dispose (GObject *object)
priv = EM_ACCOUNT_PREFS_GET_PRIVATE (object);
- if (priv->druid != NULL) {
+ if (priv->assistant != NULL) {
g_object_remove_weak_pointer (
- G_OBJECT (priv->druid), &priv->druid);
- priv->druid = NULL;
+ G_OBJECT (priv->assistant), &priv->assistant);
+ priv->assistant = NULL;
}
if (priv->editor != NULL) {
@@ -104,30 +104,30 @@ account_prefs_add_account (EAccountManager *manager)
parent = gtk_widget_get_toplevel (GTK_WIDGET (manager));
parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
- /** @HookPoint-EMConfig: New Mail Account Druid
- * @Id: org.gnome.evolution.mail.config.accountDruid
- * @Type: E_CONFIG_DRUID
+ /** @HookPoint-EMConfig: New Mail Account Assistant
+ * @Id: org.gnome.evolution.mail.config.accountAssistant
+ * @Type: E_CONFIG_ASSISTANT
* @Class: org.gnome.evolution.mail.config:1.0
* @Target: EMConfigTargetAccount
@@ -104,30 +104,30 @@ account_prefs_add_account (EAccountManager *manager)
* @Target: EMConfigTargetAccount
*
- * The new mail account druid.
+ * The new mail account assistant.
*/
emae = em_account_editor_new (